'use client'
import { Dropdown, DropdownItem, DropdownMenu, DropdownSection, DropdownTrigger, Tooltip } from '@nextui-org/react';
import { useState } from 'react';
import { ChevronDown } from 'react-feather';
import useHandleConversationStore from '@/feature/messenger/store/useHandleConversationStore';
import useConfigChatStore from '@/feature/messenger/store/chat_store/useConfigChatStore';
import { useTranslation } from '@/src/hooks/useTranslation';
import toast from 'react-hot-toast';
const ConversationOptions = ({ id_chatbot, selectedConversation }: { id_chatbot: string, selectedConversation: any }) => {

    //states 
    const handleOpenModalEnd = useHandleConversationStore(state => state.actions.handleOpenModalEnd);
    const handleOpenModalTransfer = useHandleConversationStore(state => state.actions.handleOpenModalTransfer);
    const handleSelectedConversation = useHandleConversationStore(state => state.actions.handleSelectedConversation);
    const agentsLogged = useConfigChatStore(state => state.agentsLogged);
    const { trans } = useTranslation();
    
    //hooks
    const [openDropdown, setOpenDropdown] = useState(false);
    function handleClick(event: any) {
        event.stopPropagation();
        setOpenDropdown(a => !a);
    }

    const handleOpenModalTransferLocal = () => {
        handleSelectedConversation(selectedConversation);
        if (agentsLogged.length == 0) {
            toast.success(trans("modal_conversations_transfer_message_alert_no_agents_title"));
        }else{
            handleOpenModalTransfer();
        }
    }
    
    const handleOpenModalEndLocal = () => {
        handleSelectedConversation(selectedConversation);
        handleOpenModalEnd();
    }

    return (
        <div className="flex justify-start items-center w-6 cursor-pointer text-black">
            <Dropdown placement="bottom-start">
                <Tooltip
                    placement="right"
                    content={trans('options_dropdown_title')}	
                    color="default"
                >
                    <div>
                        <DropdownTrigger>
                            <ChevronDown size={24} className='dark:text-white' />
                        </DropdownTrigger>
                    </div>
                </Tooltip>
                <DropdownMenu aria-label="Profile Actions" variant="faded" className="p-2">
                    <DropdownSection title={trans('options_dropdown_title')}>
                        <DropdownItem key="tranfer_conversation" color="default" className="text-2xl" onClick={() => handleOpenModalTransferLocal()}>
                            <p className="text-base">{trans('options_dropdown_transfer_title')}</p>
                        </DropdownItem>
                        <DropdownItem key="end_conversation" className="text-lg"  onClick={() => handleOpenModalEndLocal()}>
                            <p className="text-base">{trans('options_dropdown_end_session_title')}</p>
                        </DropdownItem>
                    </DropdownSection>
                </DropdownMenu>
            </Dropdown>
        </div>
    )
}

export default ConversationOptions